@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Ported Perl from the book's C code
 
-our $VERSION = '0.0301';
+our $VERSION = '0.0400';
 
 use Moo;
 use strictures 2;
@@ -230,6 +230,21 @@ sub euclid {
 }
 
 
+sub interval2seq {
+    my ($self, $intervals) = @_;
+    my @sequences;
+    for my $i (@$intervals) {
+        my @bitstring;
+        for my $j (@$i) {
+            my $bits = '1' . '0' x ($j - 1);
+            push @bitstring, split //, $bits;
+        }
+        push @sequences, \@bitstring;
+    }
+    return \@sequences;
+}
+
+
 sub invert_at {
     my ($self, $n, $parts) = @_;
     my @head = @$parts[ 0 .. $n - 1 ];
@@ -489,6 +504,17 @@ sub _allowed { # is p one of the parts?
     return any { $p == $_ } @$parts;
 }
 
+
+sub seq2interval {
+    my ($self, $sequences) = @_;
+    my @intervals;
+    for my $i (@$sequences) {
+        my $string = join '', @$i;
+        push @intervals, [ map { length $_ } grep { $_ } split /(10*)/, $string ];
+    }
+    return \@intervals;
+}
+
 1;
 
 __END__
@@ -503,7 +529,7 @@ Music::CreatingRhythms - Ported Perl from the book's C code
 
 =head1 VERSION
 
-version 0.0301
+version 0.0400
 
 =head1 SYNOPSIS
 
@@ -656,6 +682,18 @@ Examples:
   $got = $mcr->euclid(3, 4); # [1,1,0,1]
   $got = $mcr->euclid(4, 4); # [1,1,1,1]
 
+=head2 interval2seq
+
+  $sequences = $mcr->interval2seq($intervals);
+
+Convert B<intervals> of the form C<[2,3]> into a set of binary
+sequences.
+
+Examples:
+
+  $got = $mcr->interval2seq([[1,2,3]]);     # [[1,1,0,1,0,0]]
+  $got = $mcr->interval2seq([[1],[2],[3]]); # [[1],[1,0],[1,0,0]]
+
 =head2 invert_at
 
   $sequence = $mcr->invert_at($n, $parts);
@@ -831,6 +869,18 @@ Examples:
   $got = $mcr->rotate_n(4, $parts); # 0 1 0 0 1
   $got = $mcr->rotate_n(5, $parts); # 1 0 1 0 0
 
+=head2 seq2interval
+
+  $intervals = $mcr->seq2interval($sequences);
+
+Convert binary B<sequences> of the form C<[[1,0],[1,0,0]]> into a set
+of intervals of the form C<[[2],[3]]>.
+
+Examples:
+
+  $got = $mcr->seq2interval([[1,1,0,1,0,0]]);     # [[1,2,3]]
+  $got = $mcr->seq2interval([[1],[1,0],[1,0,0]]); # [[1],[2],[3]]
+
 =head1 SEE ALSO
 
 L<https://abrazol.com/books/rhythm1/> "Creating Rhythms"
